==> mtxp-0.0.157-py3-none-any.whl: app_mtxpagent.py <==
#!/use/bin/env python3
from subprocess import CompletedProcess
import sys
from pathlib import Path
import os
from os.path import join
from mtlibs import process_helper
from dotenv import load_dotenv, find_dotenv
import logging
import json
import traceback
from flask import Flask, request
import subprocess
import traceback
import shlex
import requests
import click
from flask import Flask
from flask.cli import with_appcontext
from flask.cli import FlaskGroup
import time
import threading
import yaml
from .services import start_all_services
from .config import config
from .services.pf import PfService
from .services.pf_agent import PfClientAgent

ENV_FILE = find_dotenv()
if ENV_FILE:
    load_dotenv(ENV_FILE)

logging.basicConfig(level=logging.DEBUG,
                    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)
data_dir = join(Path(__file__).parent, "data")
def create_app():
    app = Flask('mtxpagent')
    app.config.from_object(config['development'])  # 获取相应的配置类
    from .admin import admin_blue
    from .user import user_blue

    app.register_blueprint(admin_blue)
    app.register_blueprint(user_blue)

    from .mtxp import mtxp_blue
    app.register_blueprint(mtxp_blue)
    return app

app = create_app()

# API_PREFIX = app.config.get("API_PREFIX", "/mtpapi")

# @app.cli.command("hello_command")
# @click.argument("ccurl")
# @with_appcontext
def entry_agent():
    """本地代理入口"""
    if len(sys.argv) <=1:
        logger.info("need url args")
        return 
    ccurl = sys.argv[1]
    if ccurl:
        # 后台线程
        PfClientAgent(ccurl).start()
        # logger.info(f" 启动参数: {sys.argv} ")
        # logger.info(f"ccurl : {ccurl}")
        # def initAgent():
        #     config_url = f"{ccurl}/mtxp/tun_config"
        #     logger.info(f"config_url {config_url}")
        #     x = requests.get(config_url)
        #     jsonData= x.json()
        #     logger.info(f"配置数据 {jsonData}")
        #     # logger.info(f"启动端口转发")
        #     pf_items = jsonData["data"]["pf"]["items"]
        #     for item in pf_items:
        #         logger.info(f"(TODO)启动一个端口转发 {item}")
        #         # startup_pf(item["rhost"],item["rport"],item["lhost"], item["lport"])
        # initAgent()
        app.run(debug=True, host='0.0.0.0', port=5500)

==> mtxp-0.0.160-py3-none-any.whl: app_mtxpagent.py <==
#!/use/bin/env python3
from subprocess import CompletedProcess
import sys
from pathlib import Path
import os
from os.path import join
from mtlibs import process_helper
from dotenv import load_dotenv, find_dotenv
import logging
import json
import traceback
from flask import Flask, request
import subprocess
import traceback
import shlex
import requests
import click
from flask import Flask
from flask.cli import with_appcontext
from flask.cli import FlaskGroup
import time
import threading
import yaml
from services.services import start_all_services
from config import config
from services.pf import PfService
from services.pf_agent import PfClientAgent

ENV_FILE = find_dotenv()
if ENV_FILE:
    load_dotenv(ENV_FILE)

logging.basicConfig(level=logging.DEBUG,
                    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)
data_dir = join(Path(__file__).parent, "data")
def create_app():
    app = Flask('mtxpagent')
    app.config.from_object(config['development'])  # 获取相应的配置类
    from admin import admin_blue
    from user import user_blue

    app.register_blueprint(admin_blue)
    app.register_blueprint(user_blue)

    from mtxp import mtxp_blue
    app.register_blueprint(mtxp_blue)
    return app

app = create_app()

# API_PREFIX = app.config.get("API_PREFIX", "/mtpapi")

# @app.cli.command("hello_command")
# @click.argument("ccurl")
# @with_appcontext
def main():
    """本地代理入口"""
    if len(sys.argv) <=1:
        logger.info("need url args")
        return 
    ccurl = sys.argv[1]
    if ccurl:
        # 后台线程
        PfClientAgent(ccurl).start()
        # logger.info(f" 启动参数: {sys.argv} ")
        # logger.info(f"ccurl : {ccurl}")
        # def initAgent():
        #     config_url = f"{ccurl}/mtxp/tun_config"
        #     logger.info(f"config_url {config_url}")
        #     x = requests.get(config_url)
        #     jsonData= x.json()
        #     logger.info(f"配置数据 {jsonData}")
        #     # logger.info(f"启动端口转发")
        #     pf_items = jsonData["data"]["pf"]["items"]
        #     for item in pf_items:
        #         logger.info(f"(TODO)启动一个端口转发 {item}")
        #         # startup_pf(item["rhost"],item["rport"],item["lhost"], item["lport"])
        # initAgent()
        app.run(debug=True, host='0.0.0.0', port=5500)

if __name__ == "__main__":
    main()
